==> apache-plc4x-0.10.0-source-release.zip: apache-plc4x-0.10.0/plc4j/tools/opm/src/test/java/org/apache/plc4x/java/opm/SimpleAliasRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.java.opm;

import org.assertj.core.api.WithAssertions;
import org.junit.jupiter.api.Test;

import java.util.HashMap;
import java.util.NoSuchElementException;

import static org.junit.jupiter.api.Assertions.*;

public class SimpleAliasRegistryTest implements WithAssertions {

    public static final String ADDRESS = "DB2:1234";
    public static final String ALIAS = "some_field";

    @Test
    public void register_containsValue() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();
        registry.register(ALIAS, ADDRESS);

        // Perform checks
        checkMethods(registry);
    }

    @Test
    public void defaultMap_containsValue() {
        HashMap<String, String> map = new HashMap<>();
        map.put(ALIAS, ADDRESS);
        SimpleAliasRegistry registry = new SimpleAliasRegistry(map);

        // Perform checks
        checkMethods(registry);
    }

    @Test
    public void canResolve_unknownAlias_returnFalse() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();

        assertFalse(registry.canResolve(ALIAS));
    }

    @Test
    public void resolve_unknownAlias_throws() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();

        assertThatThrownBy(() -> registry.resolve(ALIAS))
            .isInstanceOf(NoSuchElementException.class);

    }

    private void checkMethods(SimpleAliasRegistry registry) {
        // Can Resolve
        assertTrue(registry.canResolve(ALIAS));
        assertTrue(registry.canResolve("unknown_connection", ALIAS));

        // Resolve
        assertEquals(ADDRESS, registry.resolve(ALIAS));
        assertEquals(ADDRESS, registry.resolve("unknown_connection", ALIAS));
    }
}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4j/tools/opm/src/test/java/org/apache/plc4x/java/opm/SimpleAliasRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.java.opm;

import org.assertj.core.api.WithAssertions;
import org.junit.jupiter.api.Test;

import java.util.HashMap;
import java.util.NoSuchElementException;

import static org.junit.jupiter.api.Assertions.*;

public class SimpleAliasRegistryTest implements WithAssertions {

    public static final String ADDRESS = "DB2:1234";
    public static final String ALIAS = "some_tag";

    @Test
    public void register_containsValue() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();
        registry.register(ALIAS, ADDRESS);

        // Perform checks
        checkMethods(registry);
    }

    @Test
    public void defaultMap_containsValue() {
        HashMap<String, String> map = new HashMap<>();
        map.put(ALIAS, ADDRESS);
        SimpleAliasRegistry registry = new SimpleAliasRegistry(map);

        // Perform checks
        checkMethods(registry);
    }

    @Test
    public void canResolve_unknownAlias_returnFalse() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();

        assertFalse(registry.canResolve(ALIAS));
    }

    @Test
    public void resolve_unknownAlias_throws() {
        SimpleAliasRegistry registry = new SimpleAliasRegistry();

        assertThatThrownBy(() -> registry.resolve(ALIAS))
            .isInstanceOf(NoSuchElementException.class);

    }

    private void checkMethods(SimpleAliasRegistry registry) {
        // Can Resolve
        assertTrue(registry.canResolve(ALIAS));
        assertTrue(registry.canResolve("unknown_connection", ALIAS));

        // Resolve
        assertEquals(ADDRESS, registry.resolve(ALIAS));
        assertEquals(ADDRESS, registry.resolve("unknown_connection", ALIAS));
    }
}
